from datetime import datetime
import logging

from jinja2 import BaseLoader, TemplateNotFound
from p2.store.client import Client

class P2Loader(BaseLoader):

    def __init__(self, p2_store_url):
        self.p2_store_url = p2_store_url

    def get_source(self, environment, template):
        client = Client(self.p2_store_url)
        log = logging.getLogger(__name__)
        templates = client.select(
            table='experiments',
            fetch=['data', 'last_update_time'],
            filter={
                'filename': template,
                'type': 'template'
            })

        if templates is None:
            raise TemplateNotFound(template)
        source = templates[0]['data']
        updated = datetime.timestamp(
            datetime.fromisoformat(templates[0]['last_update_time'])
        )
        log.debug(f"Template:\n{template}")
        log.debug(f"Last updated: {updated}")

        return source, template, updated


