#!/usr/bin/env python
import argparse
import os
from datetime import datetime
from jinja2 import Environment, FunctionLoader, select_autoescape
from jinja2 import BaseLoader, TemplateNotFound
from p2.store.client import Client

parser = argparse.ArgumentParser()
parser.add_argument("--filename", help="template filename", required=True)
parser.add_argument("--p2_store_url", help="P2 store url", required=True)

args = parser.parse_args()

class P2Loader(BaseLoader):

    def __init__(self, p2_store_url):
        self.p2_store_url = p2_store_url

    def get_source(self, environment, template):
        import pdb;pdb.set_trace()

        client = Client(self.p2_store_url)
        templates = client.select(
            table='experiments',
            fetch=['data', 'last_update_time'],
            filter={
                'filename': template
            })

        if templates is None:
            raise TemplateNotFound(template)
        source = templates[0]['data']
        updated = datetime.timestamp(
            datetime.fromisoformat(templates[0]['last_update_time'])
        )
        print(f"Template:\n{template}")
        print(f"Last updated: {updated}")
        return source, template, updated

env = Environment(
    loader=P2Loader(args.p2_store_url),
    autoescape=select_autoescape(['json']),
    trim_blocks=True
)

static_params={
    'params': {
        'check_timeout': 80,
        'configuration': {
            'grafana_api_token': {
                'dashboardId': 0,
                'host': 'grafana.tools.cosmic.sky',
                'port': 80,
                'protocol': 'http'
            }
        },
        'controls': [{
            'name': 'Tracing to grafana',
            'provider': {
                'module': 'chaosdb.grafana_api_token',
                'type': 'python'
            }
        }],
        'scale_down_timeout': 180,
        'secrets': {
            'kubernetes': {
                'KUBERNETES_CONTEXT': 'nbcu-int-nft-useast2',
                'KUBERNETES_HOST': 'https://nbcu-master.int-nft.aws-us-east-2.ce.nbcuott.com'
            }
        }
    }
}

target_params={'target': {'context': 'nbcu-int-nft-useast2',
            'id': 1542,
            'kind': 'namespace',
            'last_updated': '2021-02-12T10:15:41.769878',
            'name': 'reference-app-int-nft',
            'parent_id': None,
            'profile': {'area': 'core',
                        'area_owner': 'mansoor.fazil',
                        'area_owner_email': 'mansoor.fazil@sky.uk',
                        'name': 'reference-app-int-nft',
                        'team': 'core-community'},
            'status': 'active'}}

t = env.get_template(args.filename)
experiment = t.render( {**static_params, **target_params} )
print (f"Experiment:\n{experiment}")


