#!/usr/bin/env python3.9
import os
import sys
import traceback
import argparse
import json
import subprocess
import requests
from datetime import datetime
from croniter import croniter

import http.client as http_client
http_client.HTTPConnection.debuglevel = 1

from p2.store.client import Client
from p2.tools.driver import get_driver
from p2.logging import HttpLogger
# runners ----------------------------
from p2.agent.template import Runner
from p2.agent.experiment import Runner

parser = argparse.ArgumentParser()
parser.add_argument("--p2_store_url", help="P2 store url", required=True)
parser.add_argument("--filename", help="Experiment/template filename", required=True)
parser.add_argument("--driver", help="p2.agent driver (experiment/template)", required=True)
parser.add_argument("--session_id", help="Experiment session id", required=True)
parser.add_argument("--campaign_id", help="test campaign id")
args = parser.parse_args()

p2_store_url = args.p2_store_url
filename     = args.filename
exp_id       = args.session_id
campaign_id  = args.campaign_id
driver       = args.driver

try:
    runner = get_driver(
        module = 'p2.agent',
        driver = driver,
        class_name = 'Runner',
        p2_store_url = p2_store_url,
        filename = filename,
        exp_id = exp_id,
        campaign_id = campaign_id
    )
    runner.run()
except Exception as e:
    print("Error executing runner: {}".format(e))

    exc_type, exc_value, exc_traceback = sys.exc_info()
    print("*** traceback ***")
    traceback.print_tb(exc_traceback, limit=1, file=sys.stdout)
    print("*** print_exception:")
    traceback.print_exception(exc_type, exc_value, exc_traceback,
                              limit=2, file=sys.stdout)
    exit(-1)
