#!/usr/bin/env python3.9
# this script just runs a template processing it with the parameters it receives in
# input. This script is made to run failover tests...

import os
import sys
import argparse
import json
import subprocess
import requests
import logging
from datetime import datetime
from croniter import croniter
from uuid import uuid1
from jinja2 import BaseLoader, TemplateNotFound
from jinja2 import Environment, FunctionLoader, select_autoescape

import http.client as http_client
http_client.HTTPConnection.debuglevel = 1

from p2.store.client import Client
from p2.logging import HttpLogger
from p2loader import P2Loader

parser = argparse.ArgumentParser()
parser.add_argument("--p2_store_url", help="P2 store url", required=True)
parser.add_argument("--filename", help="Template filename", required=True)
parser.add_argument("--namespace", help="Target namespace", required=True)
parser.add_argument("--deployment", help="Target deployment", required=True)
parser.add_argument("--replicas", help="Target deployment replicas", required=True)
parser.add_argument("--context", required=True, help="The K8s context")
args = parser.parse_args()

p2_store_url = args.p2_store_url
filename     = args.filename
namespace    = args.namespace
deployment   = args.deployment
replicas     = args.replicas
context      = args.context

experiment_name = filename + "_" + str(uuid1())[:8]

log_obj = HttpLogger(
    level   = logging.DEBUG,
    silent  = False,
    name    = experiment_name,
    p2_store_url = p2_store_url
)
log = log_obj.getLogger()

try:
    client = Client(p2_store_url)

    template_rec = client.select(
        table='experiments',
        filter={
            'filename': filename,
            'type': 'template'
        })
    if template_rec is None:
        raise Exception(f"Template {filename} not found")

    static_params = template_rec[0]['profile']
    static_params['namespace'] = namespace
    static_params['deployment'] = deployment
    static_params['replicas'] = replicas
    static_params['context'] = context

    env = Environment(
        loader=P2Loader(p2_store_url),
        autoescape=select_autoescape(['json'])
    )

    t = env.get_template(filename)
    experiment = t.render(static_params)

    template_rec[0]['filename'] = experiment_name
    template_rec[0]['description'] = f"Scale deployment {deployment} of namespace {namespace} to {replicas} replicas"
    template_rec[0]['data'] = experiment
    template_rec[0]['type'] = 'experiment'

    # store new experiment back into p2.store...
    res = client.add(
        table='experiments',
        record=template_rec[0]
    )
    if res is None:
        raise Exception(
            f"Can't add experiment {experiment_name} out of template {filename}"
        )

    experiment_url = p2_store_url+'/experiment/'+template_rec[0]['filename']
    process = subprocess.run(["chaos", "run", experiment_url], capture_output=True)

    output = process.stderr.decode()
    log.debug("---------- Process stderr --------------")
    log.debug(output)

except Exception as e:
    print("Error executing runner: {}".format(e))
    exit(-1)

