import unittest
import sys
import os
from psycopg2 import connect, extensions, sql
from uuid import uuid1

from p2.agent import cronjobs
from p2.agent.config import Config
from p2.driver.k8s import k8s
from p2.tools.prepare_db import setUpDB, tearDownDB

class TestCronjobs(unittest.TestCase):

    def setUp(self):
        setUpDB()
        self.config = Config()

    def tearDown(self):
        #tearDownDB()
        pass

    def test_create_cronjob(self):
        name = str(uuid1())
        cron_id = cronjobs.create_cronjob(
                context='minikube',
                name=name,
                namespace=self.config.k8s.get('namespace', 'default'),
                filename='create-remove-dir',
                crontab='*/2 * * * *',
                image=self.config.cronjobs.get('image'),
                command = [
                    '/app/run-exp.py',
                    '--filename',
                    'create-remove-dir',
                    '--session_id',
                    'create-remove-dir-1234',
                    '--p2_store_url',
                    'http://127.0.0.1:6000/store',
                    '--driver',
                    'experiment'
                ],
                p2_store_endpoint=self.config.cronjobs.get('p2_store_endpoint')
                )
        assert cron_id == name

        k8s_obj = k8s.Cron(context='minikube', namespace=self.config.k8s.get('namespace', 'default'))
        res = k8s_obj.delete_cronjob(cron_id)
        assert cron_id == res
