import unittest
import requests
import os
import json
import logging

from uuid import uuid1

import http.client as http_client
http_client.HTTPConnection.debuglevel = 1

# You must initialize logging, otherwise you'll not see debug output.
logging.getLogger().setLevel(logging.DEBUG)
requests_log = logging.getLogger("requests.packages.urllib3")
requests_log.setLevel(logging.DEBUG)
requests_log.propagate = True

base_url = 'http://localhost:5000/agent'
headers = {'Content-Type': 'application/json' }

class TestP2AgentServer(unittest.TestCase):
    """
    These tests give for granted the following stmts:
        - you use postgresql
        - postgresql is installed locally
        - you have full access as postgres user
        - you have a p2store database
    The setup method will create a test db
    The teardown method will delete it
    """

    def setUp(self):
        os.environ['DB_P2STORE_USER']   = 'postgres'
        os.environ['DB_P2STORE_HOST']   = 'localhost'
        os.environ['DB_P2STORE_DBNAME'] = 'p2store_test'
        os.environ['P2_STORE_URL']      = 'http://localhost:6000/store'

    def test_p2agent_createJob(self):
        filename = 'create-remove-dir-template'
        exp_id = filename+'-'+str(uuid1())[:8]
        url = base_url + '/k8s/job/minikube/'+exp_id
        resp = requests.post(
                url,
                headers=headers,
                json={
                    'image': 'registry.tools.cosmic.sky/chaos-engineering/chaos-engineering/chaos-toolkit-int-nft-job:0.4.3',
                    'command': [
                        "./run-exp.py",
                        '--filename',
                        'create-remove-dir-template',
                        '--session_id',
                        'create-remove-dir-template-1234',
                        '--p2_store_url',
                        'http://127.0.0.1:6000/store',
                        '--driver',
                        'template'
                    ],
                    'name': exp_id
                },
                timeout=5)
        self.assertEqual( resp.status_code, 201)
        self.assertIsNotNone(resp.json())


    def test_p2agent_createCronjob(self):
        filename = 'create-remove-dir'
        exp_id = filename+'-'+str(uuid1())[:8]
        url = base_url + '/k8s/cronjob/minikube/'+exp_id
        resp = requests.post(
                url,
                headers=headers,
                json={
                    'crontab': '0 0 * * *',
                    'filename': filename,
                    'driver': 'experiment'
                    },
                timeout=5)
        self.assertEqual( resp.status_code, 201)
        return resp.json()

    def test_p2agent_deleteCronjob(self):
        id = self.test_p2agent_createCronjob()
        url = base_url + '/k8s/cronjob/minikube/'+id
        resp = requests.delete(
                url,
                headers=headers,
                timeout=5)
        self.assertEqual( resp.status_code, 200)
        self.assertEqual( resp.json(), id)


    def test_p2agent_get_cronjobs(self):
        id = self.test_p2agent_createCronjob()
        url = base_url + '/k8s/cronjobs/minikube'
        res = requests.get(url, headers=headers,timeout=5)
        self.assertEqual( res.status_code, 200)
        jobs = res.json()
        ids = [ j['name'] for j in jobs]
        self.assertIn(id, ids)

